Welcome to Shaker!
==================

The distributed data-plane testing tool for OpenStack.

.. toctree::
   :maxdepth: 2

   installation
   usage
   examples
   tools
   architecture
   contributing

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`

